## 변경 내용

<!-- 무엇을 왜 변경했는지 간단히 설명해 주세요 -->

## 변경 유형

- [ ] 새 기능 (feat)
- [ ] 버그 수정 (fix)
- [ ] 문서 (docs)
- [ ] 리팩토링 (refactor)

## 테스트

<!-- 어떻게 테스트했는지 설명해 주세요 -->

- [ ] KUPID 로그인 정상 동작 확인
- [ ] 기존 tool 동작에 영향 없음

## 관련 Issue

<!-- closes #이슈번호 -->
